==> block_inactive_users-8.x-1.8.tar.gz: block_inactive_users/tests/src/Kernel/BlockUsersTest.php <==
<?php

namespace Drupal\Tests\block_inactive_users\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;
use Drupal\user\Entity\User;

/**
 * Checks that automatic block of old users works as expected.
 *
 * @group block_inactive_users
 */
class BlockUsersTest extends KernelTestBase {

  use UserCreationTrait;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['block_inactive_users', 'system', 'user'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installSchema('system', ['sequences']);
    $this->installEntitySchema('user');
    $this->installConfig(['block_inactive_users']);
  }

  /**
   * Users that haven't logged in in 3 months should be blocked.
   */
  public function testInactiveUsers() {
    /* @var \Drupal\Core\Config\Config $config */
    $config = $this
      ->container
      ->get('config.factory')
      ->getEditable('block_inactive_users.settings');
    $config->set('block_inactive_users_include_never_accessed', TRUE);
    // We avoid a join in a table that does not exists.
    $config->set('block_inactive_users_exclude_roles', []);
    $config->save();

    $new_user = $this->createUser();
    $active = $this->createUser();
    $never_login = $this->createUser();
    $inactive = $this->createUser();

    $this->assertFalse($new_user->isBlocked());
    $this->assertFalse($active->isBlocked());
    $this->assertFalse($never_login->isBlocked());
    $this->assertFalse($inactive->isBlocked());

    /** @var \Drupal\Core\Database\Connection $connection */
    $connection = \Drupal::service('database');

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => strtotime('-5 days'),
      ])
      ->condition('uid', $active->id())
      ->execute();

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => strtotime('-120 days'),
      ])
      ->condition('uid', $inactive->id())
      ->execute();

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => NULL,
      ])
      ->condition('uid', $never_login->id())
      ->execute();

    block_inactive_users_block_users();

    $new_user = User::load($new_user->id());
    $active = User::load($active->id());
    $inactive = User::load($inactive->id());
    $never_login = User::load($never_login->id());

    $this->assertFalse($new_user->isBlocked());
    $this->assertFalse($active->isBlocked());
    $this->assertTrue($inactive->isBlocked());
    $this->assertTrue($never_login->isBlocked());
  }

}

==> block_inactive_users-8.x-2.2.tar.gz: block_inactive_users/tests/src/Kernel/BlockUsersTest.php <==
<?php

namespace Drupal\Tests\block_inactive_users\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\user\Traits\UserCreationTrait;
use Drupal\user\Entity\User;

/**
 * Checks that automatic block of old users works as expected.
 *
 * @group block_inactive_users
 */
class BlockUsersTest extends KernelTestBase {

  use UserCreationTrait;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['block_inactive_users', 'system', 'user'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installSchema('system', ['sequences']);
    $this->installEntitySchema('user');
    $this->installConfig(['block_inactive_users']);
  }

  /**
   * Users that haven't logged in in 3 months should be blocked.
   */
  public function testInactiveUsers() {
    /** @var \Drupal\Core\Config\Config $config */
    $config = $this
      ->container
      ->get('config.factory')
      ->getEditable('block_inactive_users.settings');
    $config->set('block_inactive_users_include_never_accessed', TRUE);
    // We avoid a join in a table that does not exists.
    $config->set('block_inactive_users_exclude_roles', []);
    $config->save();

    $new_user = $this->createUser();
    $active = $this->createUser();
    $never_login = $this->createUser();
    $inactive = $this->createUser();

    $this->assertFalse($new_user->isBlocked());
    $this->assertFalse($active->isBlocked());
    $this->assertFalse($never_login->isBlocked());
    $this->assertFalse($inactive->isBlocked());

    /** @var \Drupal\Core\Database\Connection $connection */
    $connection = \Drupal::service('database');

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => strtotime('-5 days'),
      ])
      ->condition('uid', $active->id())
      ->execute();

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => strtotime('-120 days'),
      ])
      ->condition('uid', $inactive->id())
      ->execute();

    $connection->update('users_field_data')
      ->fields([
        'created' => strtotime('-1 year'),
        'login' => NULL,
      ])
      ->condition('uid', $never_login->id())
      ->execute();

    block_inactive_users_block_users();

    $new_user = User::load($new_user->id());
    $active = User::load($active->id());
    $inactive = User::load($inactive->id());
    $never_login = User::load($never_login->id());

    $this->assertFalse($new_user->isBlocked());
    $this->assertFalse($active->isBlocked());
    $this->assertTrue($inactive->isBlocked());
    $this->assertTrue($never_login->isBlocked());
  }

}
